#! /bin/tcsh -f
# usage: complet.sh bibfile
if ($#argv != 1) then
    echo "usage: complet.sh bibfile"
else
    #setting input file
    set infile = $1
    #setting bibclean output file
    set bibcleanout = $infile.clean
    #setting bibclean error-log file
    set bibcleanerr = $bibcleanout.errors
    #set bibcleanerrerr = $bibcleanerr.error
    #setting bibparse error-log file
    set bibparseerr = $infile.bibparse.errors
    #setting bibxml output file
    set bibxmlout = $infile.noconv.xml
    #setting utf conversion error-log file
    set converr = $infile.conv.errors
    #setting final output file
    set outfile = $infile.inter.xml
    #setting final file
    set finalfile = $infile.xml

    echo "Parsing file $infile..."

    #starting bibclean with some options
    echo "Starting bibclean..."
    ./bibclean -delete-empty-values -error-log $bibcleanerr $infile > $bibcleanout
    #! /bin/tcsh -f
    # starts error.pl

    set error = $bibcleanerr.error.html
    set warning = $bibcleanerr.warning.html

    (./error.pl $bibcleanerr > $warning ) > & $error

    echo "bibclean output file: $bibcleanout"

    echo "Starting Bibparse.."
    ./bibparse $bibcleanout > & $bibparseerr

    echo "Bibparse finished.."

    echo "Starting bibxmlparse..."
    ./bibxmlparse $bibcleanout > $bibxmlout
    echo "bibxmlparse output file: $bibxmlout"

    echo "Converting Latex special characters..."
    #! /bin/tcsh -f
    # starts the tex2utf.pl script
    #redirects STDOUT to $2 (outfile)
    #redirects STDERR to $3 (errfile)
    (/usr/local/bin/perl ./tex2utf.pl $bibxmlout > $outfile ) > & $converr
    echo "Parsing finished!"
    
    /usr/local/bin/perl iso2utf.pl $outfile > $outfile.utf
    xsltproc i2bibtexml.xsl $outfile.utf > $infile.xml 
   # The next step is optional, see description of the "conv" programme
    ./conv  < $infile.xml  > zwi
    mv zwi $infile.xml
    echo "output file:  $infile.xml"
endif
